/*
 * JCuda - Java bindings for NVIDIA CUDA driver and runtime API
 * http://www.jcuda.org
 *
 * Copyright 2009-2012 Marco Hutter - http://www.jcuda.org
 */

package org.jcuda.samples.matrix.cg;

/**
 * Default implementation of a {@link FloatMatrixHostDense}.
 * The data is stored in column-major order.
 */
class DefaultFloatMatrixHostDense implements FloatMatrixHostDense
{
    /**
     * The number of rows 
     */
    private final int numRows;
    
    /**
     * The number of columns 
     */
    private final int numCols;

    /**
     * The data 
     */
    private final float data[];
    
    
    /**
     * Creates a new matrix with the given number of rows and columns
     * 
     * @param numRows The number of rows
     * @param numCols The number of columns
     */
    DefaultFloatMatrixHostDense(int numRows, int numCols)
    {
        this(numRows, numCols, new float[numRows * numCols]);
    }
    
    /**
     * Creates a new matrix with the given number of rows and columns,
     * and the given data
     * 
     * @param numRows The number of rows
     * @param numCols The number of columns
     * @param data The data 
     */
    DefaultFloatMatrixHostDense(int numRows, int numCols, float data[])
    {
        this.numRows = numRows;
        this.numCols = numCols;
        this.data = data;
    }
    
    @Override
    public int getNumRows()
    {
        return numRows;
    }
    @Override
    public int getNumCols()
    {
        return numCols;
    }
    @Override
    public float get(int r, int c)
    {
        return data[c+r*getNumCols()];
    }
    @Override
    public float[] getData()
    {
        return data;
    }
    
    @Override
    public void set(int r, int c, float value)
    {
        data[c+r*getNumCols()] = value;
    }
    
    @Override
    public String toString()
    {
        return Matrices.toString2D(this);
    }
    
}